/*******************************************************************************
Module Name: mojo_top
Module Desc: Top-level module for the Mojo V3

Author: Ryan Clarke (modified from Embedded Micro)
Data:   7 August 2015
E-Mail: rfclarke@alum.wpi.edu
*******************************************************************************/

module mojo_top(
    // 50 MHz clock and reset button (active low)
    input clk,
    input rst_n,

    // Input from AVR CCLK (high when AVR ready)
    input cclk,

    // Onboard LEDs
    output[7:0]led,
    
    // AVR SPI connections
    output spi_miso,
    input spi_ss,
    input spi_mosi,
    input spi_sck,
    
    // AVR ADC channel select
    output [3:0] spi_channel,
    
    // AVR Serial connections
    input avr_tx, // AVR Tx => FPGA Rx
    output avr_rx, // AVR Rx => FPGA Tx
    input avr_rx_busy, // AVR Rx buffer full
    
    // SPI Serial ROM connections
    input rom_sck,
    input rom_mosi,
    output rom_miso,
    input rom_ss_n
    );

    wire rst = ~rst_n; // make reset active high

    // these signals should be high-z when not used
    assign spi_miso = 1'bz;
    assign avr_rx = 1'bz;
    assign spi_channel = 4'bzzzz;

    // LEDs off
    assign led = 8'b0;

    // instantiate the SPI Serial ROM
    spi_rom spi_rom_u
        (
        .clk(clk),
        .rst_n(rst_n),
        .sck(rom_sck),
        .mosi(rom_mosi),
        .miso(rom_miso),
        .ss_n(rom_ss_n)
        );
    
endmodule
