/*******************************************************************************
Module Name: spi_rom
Module Desc: SPI Serial ROM

Author: Ryan Clarke
Data:   7 August 2015
E-Mail: rfclarke@alum.wpi.edu
*******************************************************************************/

module spi_rom
    (
    // 50 MHz clock and reset button (active low)
    input wire clk,
    input wire rst_n,
    
    // SPI connections
    input wire sck,
    input wire mosi,
    output wire miso,
    input wire ss_n
    );
    
    // SPI data width
    localparam N = 8;
    
    // I/O control module interface connections
    wire data_req, data_rdy, data_ack, cmd_rdy;
    wire [N-1:0] data_out, cmd_in;
    
    // ROM interface connections
    wire [3:0] addr;
    wire [7:0] data;
    
    // instantiate SPI slave (default parameters for mode and prefetch)
    spi_slave #(.N(N)) spi_slave_u
        (
        .clk_i(clk),
        .spi_sck_i(sck),
        .spi_mosi_i(mosi),
        .spi_miso_o(miso),
        .spi_ssel_i(ss_n),
        .di_req_o(data_req),
        .di_i(data_out),
        .wren_i(data_rdy),
        .wr_ack_o(data_ack),
        .do_valid_o(cmd_rdy),
        .do_o(cmd_in)
        );
    
    // instantiate I/O control module
    io_control #(.N(N)) io_control_u
        (
        .clk(clk),
        .rst_n(rst_n),
        .data_req(data_req),
        .data_out(data_out),
        .data_rdy(data_rdy),
        .data_ack(data_ack),
        .cmd_rdy(cmd_rdy),
        .cmd_in(cmd_in),
        .addr(addr),
        .data(data)
        );
        
    // instantiate 16 x 8-bit synchronous ROM 
    rom_16x8 rom_16x8_u
        (
        .clk(clk),
        .addr(addr),
        .data(data)
        );
    
endmodule
