/*******************************************************************************
Module Name: spi_rom_tb
Module Desc: SPI Serial ROM test bench

Author: Ryan Clarke
Data:   7 August 2015
E-Mail: rfclarke@alum.wpi.edu
*******************************************************************************/

`timescale 1 ns / 10 ps

module spi_rom_tb;
    
    // clock periods (ns)
    localparam T_clk = 20;      // 50 MHz clock
    localparam T_sck = 1000;    // 1 MHz SPI clock

	// SPI Serial ROM connections
	reg clk, rst_n;
	reg sck, mosi, ss_n;
	wire miso;

	// instantiate SPI Serial ROM
	spi_rom spi_rom_uut (
		.clk(clk), 
		.rst_n(rst_n),
		.sck(sck),
        .mosi(mosi),
        .miso(miso),
        .ss_n(ss_n)
	);
    
    // SPI data width
    localparam N = 8;

    // 50 MHz clock
    always begin
        clk = 1;
        #(T_clk/2);
        
        clk = 0;
        #(T_clk/2);
    end        

    // reset for first clock period
    initial begin
        rst_n = 0;
        #(T_clk);
        
        rst_n = 1;
    end

    integer i;
    integer cmd = 8'b0001_0100;		// set ROM read address to 0x4

	// main simulation
    initial begin
		// initialize SPI
        sck = 0;
        mosi = 1'bz;
        ss_n = 1;
        #(T_sck);
        
        // slave select SPI Serial ROM
        ss_n = 0;
        
        // send a command to the SPI Serial ROM to set the read address to 0x4
        for(i = 0; i < N; i = i + 1) begin
            mosi = cmd >> (N - i - 1);
            #(T_sck);
            
            sck = 1;
            #(T_sck);
            
            sck = 0;
        end
        
        mosi = 1'bx;
        #(T_sck);
        
        // read SPI Serial ROM data
        for(i = 0; i < N; i = i + 1) begin
            sck = 1;
            #(T_sck);
            
            sck = 0;
            #(T_sck);
        end
        
        // read another byte from the SPI Serial ROM
        for(i = 0; i < N; i = i + 1) begin
            sck = 1;
            #(T_sck);
            
            sck = 0;
            #(T_sck);
        end
        
        // deselect the SPI Serial ROM
        ss_n = 1;
        mosi = 1'bz;
        #(T_sck);
        
        $stop;        
	end
      
endmodule

