/*******************************************************************************
 * Module Name: spi.c
 * Module Desc: SPI functions
 * 
 * Author: Ryan Clarke
 * Date:   7 August 2015
 * Email:  rfclarke@alum.wpi.edu
 ******************************************************************************/

#include <xc.h>

#include <stdint.h>

#define SCK1OUT 8   // SPI1 Clock Output
#define SDO1    7   // SPI1 Data Output
#define RP7     7   // SPI1 Data Input

void spi1_init(void)
{
    // SPI Setup
    // - assign SCK to RP9 (pin 18)
    // - assign SDO to RP8 (pin 17)
    // - assign SDI to RP7 (pin 16)
    // - SPI master mode enable (MSTEN)
    // - 1 MHz SPI clock (PPRE, SPRE)
    // - clear overflow bit (SPIROV)
    // - SPI enable (SPIEN)
    RPOR4bits.RP9R = SCK1OUT;
    RPOR4bits.RP8R = SDO1;
    RPINR20bits.SDI1R  = RP7;
    SPI1CON1bits.MSTEN = 1;
    SPI1CON1bits.CKE = 1;
    SPI1CON1bits.PPRE = 1;
    SPI1CON1bits.SPRE = 7;
    SPI1STATbits.SPIROV = 0;
    SPI1STATbits.SPIEN = 1;
}

uint8_t spi1_transfer(uint8_t data_out)
{
    // each SPI transaction consists of a transmit and receive
    
    uint8_t data_in;
    
    while(SPI1STATbits.SPITBF);
    SPI1BUF = data_out;
    
    while(!SPI1STATbits.SPIRBF);
    data_in = SPI1BUF;
    
    return data_in;
}
